/*
==========================================
Name:		HD44780.c
Author:		POSPISIL Frantisek
Created:	12/2008
Chip:		ATmega8
Frequency:	CPU 8MHz
Hardware:	HD44780 komunikace 4 bity
==========================================
*/

/* hlavickove soubory */
#include <avr/io.h>
#include <util/delay.h>
#include "HD44780.h"

/* definice funkci */
// ===========================================================================
void LCD_PrTisiciny(unsigned int val) // decimalne tisiciny
{
	LCD_WriteData((val / 10000) + 0x30 );
	val = val % 10000;
	LCD_WriteData((val / 1000) + 0x30 );
	LCD_WriteData( ',' );
	val = val % 1000;
	LCD_WriteData((val / 100) + 0x30 );
	val = val % 100;
	LCD_WriteData((val / 10) + 0x30 );
	LCD_WriteData((val % 10) + 0x30);
}
// ===========================================================================
void LCD_PrHex(unsigned char val) // dva znaky - 8 bitu
{
	unsigned char znak;
	znak = val / 16;
	if (znak < 10)
	LCD_WriteData(znak+0x30);
	else
	LCD_WriteData(znak+0x37);
	znak = val % 16;
	if (znak < 10)
	LCD_WriteData(znak+0x30);
	else
	LCD_WriteData(znak+0x37);
}

// ===========================================================================
void LCD_PrPwm(unsigned int val) // vypisuje procenta 8 znaku
{
	unsigned char znak;
	unsigned char nula = 0;
	znak = val / 1000;
	val = val % 1000;
	if (znak!=0)
	{
		LCD_WriteData( znak + 0x30 );
		nula = 1;
	}
	else LCD_WriteData( ' ' );
	znak = val / 100;
	val = val % 100;
	if ((znak!=0) || (nula!=0))
	{
		LCD_WriteData( znak + 0x30 );
	}
	else LCD_WriteData( ' ' );
	znak = val / 10;
	LCD_WriteData( znak + 0x30 );
	LCD_WriteData( ',' );
	LCD_WriteData((val % 10) + 0x30);
	LCD_WriteCString( "%  " );
}

// ===========================================================================
void LCD_PrTemp(unsigned int val) // vypisuje teplotu 8 znaku
{
	unsigned char znak;
	unsigned char nula = 0;
	znak = val / 1000;
	val = val % 1000;
	if (znak!=0)
	{
		LCD_WriteData( znak + 0x30 );
		nula = 1;
	}
	else LCD_WriteData( ' ' );
	znak = val / 100;
	val = val % 100;
	if ((znak!=0) || (nula!=0)) 
	{
		LCD_WriteData( znak + 0x30 );
	}	
	else LCD_WriteData( ' ' );
	znak = val / 10;
	LCD_WriteData( znak + 0x30 );
	LCD_WriteData( ',' );
	LCD_WriteData((val % 10) + 0x30);
	LCD_WriteData( 0xDF ); // znak stupen
	LCD_WriteCString( "C  " );
}

// ===========================================================================
void LCD_PrSDec(unsigned char val) // ctyri znaky - 8 bitu decimalne se znamenkem
{
  if (val&0x80)
  {
    LCD_WriteData('-');
	val = ~val+1;
  }
  else LCD_WriteData(' ');
  LCD_PrDec( val );
}

// ===========================================================================
void LCD_PrIntDec(unsigned int val) // pet znaku - 16 bitu decimalne
{
	unsigned char znak;
	unsigned char nula = 0;
	znak = val / 10000;
	val = val % 10000;
	if (znak!=0)
	{
		LCD_WriteData( znak + 0x30 );
		nula = 1;
	}
	else LCD_WriteData( ' ' );
	znak = val / 1000;
	val = val % 1000;
	if ((znak!=0) || (nula!=0)) 
	{
		LCD_WriteData( znak + 0x30 );
		nula = 1;
	}	
	else LCD_WriteData( ' ' );
	znak = val / 100;
	val = val % 100;
	if ((znak!=0) || (nula!=0))
	{
		LCD_WriteData( znak + 0x30 );
		nula = 1;
	}
	else LCD_WriteData( ' ' );
	znak = val / 10;
	if ((znak!=0) || (nula!=0))
	{
		LCD_WriteData( znak + 0x30 );
		nula = 1;
	}
	else LCD_WriteData( ' ' );
	LCD_WriteData((val % 10) + 0x30);
}

// ===========================================================================
void LCD_PrDec(unsigned char val) // dva znaky - 8 bitu decimalne
{
  LCD_WriteData((val / 10) + 0x30);
  LCD_WriteData((val % 10) + 0x30);
}

// ===========================================================================
void LCD_WriteCString(const char* retezec) // vypise konstantni retezec
{
  while(*retezec != '\0')
  {
    LCD_WriteData(*retezec);
	retezec +=1;
  }
}

// ===========================================================================
void LCD_Position(unsigned char y, unsigned char x) // nastavi pozici kurzoru
{
  switch(y)
  {
    case 0: x+=0x00; break;
	case 1: x+=0x40; break;
	case 2: x+=0x14; break;
	case 3: x+=0x54; break;
  }
  LCD_WriteComm(x|0x80);
}

// ===========================================================================
void LCD_Init(void) // inicializuje displej
{
  LCD_ClrEnable();
  LCD_Clear();
  LCD_WriteComm(0x28);
  LCD_WriteComm(0x08);
  LCD_Clear();
  LCD_WriteComm(0x06);
  LCD_WriteComm(0x0C);
}

// ===========================================================================
void LCD_Clear(void) // vymaze obsah displeje a nastavi kurzor na zacatek
{
  LCD_WriteComm(1);
  _delay_ms(200);
}

// ===========================================================================
void LCD_WriteData(unsigned char val) // zapise data na displej
{
  LCD_SetData();
  _delay_us(80);
  LCD_Data = (LCD_Data & 0b11000011) | ((val >> 2) & 0b00111100);
  _delay_us(80);
  LCD_SetEnable();
  _delay_us(80);
  LCD_ClrEnable();
  _delay_us(80);
  LCD_Data = (LCD_Data & 0b11000011) | ((val << 2) & 0b00111100);
  _delay_us(80);
  LCD_SetEnable();
  _delay_us(80);
  LCD_ClrEnable();
  _delay_us(100); 
}

// ===========================================================================
void LCD_WriteComm(unsigned char val) // zapise ridici kod na displej
{
  LCD_SetCommand();
  _delay_us(80);
  LCD_Data = (LCD_Data & 0b11000011) | ((val >> 2) & 0b00111100);
  _delay_us(80);
  LCD_SetEnable();
  _delay_us(80);
  LCD_ClrEnable();
  _delay_us(80);
  LCD_Data = (LCD_Data & 0b11000011) | ((val << 2) & 0b00111100);
  _delay_us(80);
  LCD_SetEnable();
  _delay_us(80);
  LCD_ClrEnable();
  _delay_us(100);
}
