/*
 * Pajeci_stanice.c
 * Chip: ATmega8
 * Frequency: CPU 8MHz
 * Created: 20.12.2014 20:07:26
 * Author: Merlin
 * Hardware: pajeci stanice
 * Description: ovladaci program pro pajeci stanici. 
 * Tato verze je kopii predchozi, s dalsim vyvojem regulacni smycky
 */ 

/* hlavickove soubory */
#define	 F_CPU 8000000UL							// kmitocet systemu 8MHz
#include <util/delay.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include "Pajeci_stanice.h"
#include "HD44780.h"

int main(void)
{
	SYS_Init();										// inicializace systemu
	while(1)
    {
		LCD_Position( 0, 0 );						// prvni radek
//		LCD_PrIntDec( StandbyTimerSec );
//		LCD_WriteCString( "   " );		
		LCD_WriteCString( "Tsold = " );
		LCD_PrTemp( TempSolder );					// teplota telesa
		LCD_WriteCString( "   " );		
		LCD_Position( 1, 0 );
		LCD_PrTemp( TempSet );						// nastavena teplota
		LCD_PrPwm( SolderPWM / 8 );					// aktualni vykon v desetinach procenta
		_delay_ms( 100 );
		if ( ROT_Key() > 2 ) MENU_Global();			// ceka na stisk rotacniho koderu
		if ( RotStatus == 100 )						// jede Standby rezim
		{
			Beep( 200 );							// pipne na zacatku Standby
			while ( RotStatus == 100 )
			{
				LCD_Position( 0, 0 );				// prvni radek
				LCD_WriteCString( "Tsold = " );
				LCD_PrTemp( TempSolder );			// teplota telesa
				LCD_WriteCString( "   " );
				LCD_Position( 1, 0 );
				LCD_WriteCString( "* Standby mode *" );
				_delay_ms( 100 );
				if ( ROT_Key() > 2 ) RotStatus = 0;	// ceka na stisk rotacniho koderu
			}
			TempSet = StandbyTempBuff;
			Beep( 100 );							// pipne na konci standby
		}
    }
}

/*********************************************************************************
*
* Function Name : MENU_Global
* Description	: nastavi promenne a uklada je do EEPROM
*
*********************************************************************************/
void MENU_Global(void)
{
	unsigned char rotkey;
	
	LCD_Clear();
	RotStatus = 1;
	while( RotStatus > 0 )
	{
		StandbyTimerSec = 0;							// v menu nemuze do Standby rezimu
		switch( RotMenu )
		{
			case 0:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "1 Teplota Tmin  " ); // minimalni nastavitelna teplota
				LCD_Position( 1, 0 );
				LCD_PrTemp( TempMin );
				LCD_WriteCString( "        " );
				break;
			}
			case 1:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "2 Teplota Tmax  " ); // maximalni nastavitelna teplota
				LCD_Position( 1, 0 );
				LCD_PrTemp( TempMax );
				LCD_WriteCString( "        " );
				break;
			}
			case 2:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "3 Teplota Tset  " ); // teplota nastavena na zacatku
				LCD_Position( 1, 0 );
				LCD_PrTemp( TempSet0 );
				LCD_WriteCString( "          " );
				break;
			}
			case 3:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "4 Teplota Standb" ); // teplota pro Standby rezim
				LCD_Position( 1, 0 );
				LCD_PrTemp( StandbyTemp );
				LCD_WriteCString( "          " );
				break;
			}
			case 4:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "5 Standby Diff  " ); // rozdil vykonu, pri kterem se neprejde do Standby
				LCD_Position( 1, 0 );
				LCD_PrPwm( StandbyDifference/8 );		// vypisuje vykon v procentech
				LCD_WriteCString( "          " );
				break;
			}
			case 5:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "6 Standby Timer " ); // cas v sekundach, po kterem se jde do Standby
				LCD_Position( 1, 0 );
				LCD_PrPwm( StandbyTimerMax/6 );			// vypisuje cas v minutach
				LCD_Position( 1, 5 );
				LCD_WriteCString( " min.       " );
				break;
			}			
			case 6:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "7 Velikost pole " ); // velikost pole pro vypocet prumerne teploty
				LCD_Position( 1, 0 );
				LCD_PrIntDec( MeanMax );
				LCD_WriteCString( "           " );
				break;
			}
			case 7:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "8 Proporcionalni" ); // proporcionalni slozka regulatoru
				LCD_Position( 1, 0 );
				LCD_PrIntDec( Const1 );
				LCD_WriteCString( "            " );
				break;
			}
			case 8:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "9 Integralni    " ); // integralni slozka regulatoru
				LCD_Position( 1, 0 );
				LCD_PrIntDec( Const2 );
				LCD_WriteCString( "            " );
				break;
			}
			case 9:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "10 Primka 1     " ); // prvni konstanta pro vypocet primky
				LCD_Position( 1, 0 );
				LCD_PrIntDec( Primka1 );
				LCD_WriteCString( "            " );
				break;
			}
			case 10:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "11 Primka 2     " ); // druha konstanta pro vypocet primky
				LCD_Position( 1, 0 );
				LCD_PrIntDec( Primka2 );
				LCD_WriteCString( "            " );
				break;
			}
			case 11:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "12 Primka 3     " ); // treti konstanta pro vypocet primky
				LCD_Position( 1, 0 );
				LCD_PrIntDec( Primka3 );
				LCD_WriteCString( "            " );
				break;
			}
			case 12:
			{
				LCD_Position( 0, 0 );
				LCD_WriteCString( "U=" );
				LCD_PrIntDec( Mean );					// napise napeti z prevodniku
				LCD_WriteCString( "  " );
				LCD_PrTemp( TempSolder );				// napise vypoctenou teplotu
				LCD_Position( 1, 0 );
				LCD_PrTemp( TempMenu );					// nastavena teplota v MENU
				LCD_WriteCString( "  " );
				LCD_PrIntDec( LTC1286() );
				LCD_WriteCString( "    ");
				break;				
			}
		}
		if (RotStatus > 1)								// bude menit hodnotu, napise do rohu "SET"
		{
			LCD_Position( 1, 10 );
			LCD_WriteCString( "SET " );
			LCD_PrDec( RotStatus - 1 );
		}
		_delay_ms( 50 );
		rotkey = ROT_Key();								// ceka na stisk klavesy
		if ((rotkey > 0) && (rotkey < 20) && (RotStatus == 1))
		{
			RotStatus = RotMenu + 2;					// bude menit promenne
			rotkey = 0;
		}
		if ((rotkey > 0) && (rotkey < 20) && (RotStatus > 1))
		{
			RotStatus = 1;								// vrati se k listovani v menu
		}
		if (rotkey > 5)									// pri dlouhem stisku konci MENU
		{
			RotStatus = 0;								// ulozi veci do EEPROM
			EEPROM_Write(  0, TempMin  );				// minimalni nastavitelna teplota
			EEPROM_Write(  1, TempMax );				// maximalni nastavitelna teplota
			EEPROM_Write(  2, TempSet0 );				// teplota nastavena na zacatku
			EEPROM_Write(  3, StandbyTemp );			// teplota pro Standby rezim
			EEPROM_Write(  4, StandbyDifference );		// rozdil vykonu, pri kterem se neprejde do Standby
			EEPROM_Write(  5, StandbyTimerMax );		// cas v sekundach, po kterem se jde do Standby
			EEPROM_Write(  6, MeanMax );				// velikost pole pro vypocet prumerne teploty
			EEPROM_Write(  7, Const1 );					// proporcionalni slozka regulatoru
			EEPROM_Write(  8, Const2 );					// integralni slozka regulatoru
			EEPROM_Write(  9, Primka1 );				// prvni konstanta pro vypocet primky
			EEPROM_Write( 10, Primka2 );				// druha konstanta pro vypocet primky
			EEPROM_Write( 11, Primka3 );				// treti konstanta pro vypocet primky
		}
	}
	LCD_Clear();
}

/*********************************************************************************
*
* Function Name : INT1_vect
* Description	: preruseni INT1 obsluha rotacniho koderu na PD3 a PD4
*
*********************************************************************************/
ISR(INT1_vect)
{
    SREG = 0x00;			// zastavi globalni preruseni
	switch( RotStatus )
	{
		case 0:				// meni pozadovanou teplotu
		{
			if (( PIND&0x10) && (TempSet<TempMax)) TempSet += 5;
			if ((~PIND&0x10) && (TempSet>TempMin)) TempSet -= 5;
			break;
		}
		case 1:				// listuje v MENU_Global
		{
			if (( PIND&0x10) && (RotMenu<14)) RotMenu++;
			if ((~PIND&0x10) && (RotMenu>0)) RotMenu--;
			break;
		}	
		case 2:				// listuje v MENU_Global - Tmin
		{
			if (( PIND&0x10) && (TempMin<900)) TempMin += 10;
			if ((~PIND&0x10) && (TempMin>200)) TempMin -= 10;
			break;
		}
		case 3:				// listuje v MENU_Global - Tmax
		{
			if (( PIND&0x10) && (TempMax<5000)) TempMax += 10;
			if ((~PIND&0x10) && (TempMax>1000)) TempMax -= 10;
			break;
		}
		case 4:				// listuje v MENU_Global - Tset0
		{
			if (( PIND&0x10) && (TempSet0<TempMax)) TempSet0 += 10;
			if ((~PIND&0x10) && (TempSet0>TempMin)) TempSet0 -= 10;
			break;
		}		
		case 5:				// listuje v MENU_Global - StandbyTemp
		{
			if (( PIND&0x10) && (StandbyTemp<TempMax)) StandbyTemp += 10;
			if ((~PIND&0x10) && (StandbyTemp>TempMin)) StandbyTemp -= 10;
			break;
		}		
		case 6:				// listuje v MENU_Global - StandbyDifference
		{
			if (( PIND&0x10) && (StandbyDifference<800)) StandbyDifference +=8;
			if ((~PIND&0x10) && (StandbyDifference>  8)) StandbyDifference -=8;
			break;
		}		
		case 7:				// listuje v MENU_Global - StandbyTimerMax
		{
			if (( PIND&0x10) && (StandbyTimerMax<1200)) StandbyTimerMax +=30;
			if ((~PIND&0x10) && (StandbyTimerMax>  60)) StandbyTimerMax -=30;
			break;
		}
		case 8:				// listuje v MENU_Global - MeanMax
		{
			if (( PIND&0x10) && (MeanMax<100)) MeanMax++;
			if ((~PIND&0x10) && (MeanMax>  5)) MeanMax--;
			break;
		}
		case 9:				// listuje v MENU_Global - Const1
		{
			if (( PIND&0x10) && (Const1<20000)) Const1 += 10;
			if ((~PIND&0x10) && (Const1> 1000)) Const1 -= 10;
			break;
		}
		case 10:			// listuje v MENU_Global - Const2
		{
			if (( PIND&0x10) && (Const2<1000)) Const2++;
			if ((~PIND&0x10) && (Const2>  10)) Const2--;
			break;
		}	
		case 11:			// listuje v MENU_Global - Primka1
		{
			if (( PIND&0x10) && (Primka1<1000)) Primka1++;
			if ((~PIND&0x10) && (Primka1> 100)) Primka1--;
			break;
		}
		case 12:			// listuje v MENU_Global - Primka2
		{
			if (( PIND&0x10) && (Primka2<50000)) Primka2 ++;
			if ((~PIND&0x10) && (Primka2>10000)) Primka2 --;
			break;
		}
		case 13:			// listuje v MENU_Global - Primka3
		{
			if (( PIND&0x10) && (Primka3<1000)) Primka3++;
			if ((~PIND&0x10) && (Primka3> 100)) Primka3--;
			break;
		}
		case 14:
		{
			if (( PIND&0x10) && (TempMenu<4000)) TempMenu += 20;
			if ((~PIND&0x10) && (TempMenu> 300)) TempMenu -= 20;
			break;							
		}		
	}
	Beep( 3 );
    GICR  = 0b00000000;		// zakaze preruseni INT1
	RotTimer = 10;			// cyklu preruseni je 0.1 sekundy mezi kroky rotacniho koderu
    SREG = 0x80;			// nastavi globalni preruseni
}

/*********************************************************************************
*
* Function Name : TIMER1_CAPT_vect
* Description	: ridi BEEP, meri teplotu z DA, regulator
*
*********************************************************************************/
ISR(TIMER1_OVF_vect)
{
    SREG = 0x00;								// zastavi globalni preruseni
	// * * * * * * * * * * * * * * * * * * program pocitajici mezeru mezi kroky rotacniho koderu
	if ( RotTimer > 0 )	RotTimer--;
	else				GICR  = 0b10000000;		// povoleni preruseni INT1
	
	// * * * * * * * * * * * * * * * * * * program BEEP
	if ( BeepCounter > 0 ) BeepCounter--;		// pocita kmity piezomenice
	else BEEP_Clr;								// kdyz je 0, zastavi vystup
	if ( Rozdil > 50 ) BeepTemp = 0;
	if (( Rozdil == 0) && ( BeepTemp == 0))
	{
		BeepTemp = 1;
		Beep( 100 );							// pipne, kdyz je dosazeno teploty
	}
	
	// * * * * * * * * * * * * * * * * * * program mereni
	MeanArray[ MeanPointer ] = LTC1286();		// nameri se hodnota
	MeanAdd += MeanArray[ MeanPointer ];		// pricte namerenou hodnotu
	if (MeanPointer < MeanMax) MeanPointer++;
	else MeanPointer=0;							// ovladani ukazatele v poli
	MeanAdd -= MeanArray[ MeanPointer ];		// odecte namerenou z konce pole
	MeanOld = Mean;								// ulozi hodnotu z minuleho mereni
	Mean = (unsigned int) (MeanAdd / MeanMax);	// vypocte prumer

	
	// * * * * * * * * * * * * * * * * * * vypocte teplotu z napeti
	TempSolder  = (unsigned int) (((Primka1 * Mean) + Primka2) / Primka3);
	if(RotStatus == 11) Rozdil = TempMenu - TempSolder;	// jede v menu
	else Rozdil	= TempSet - TempSolder;
		
	// * * * * * * * * * * * * * * * * * * vzorec regulatoru

	SolderPWM1 = Const1;
	SolderPWM2 = Const2;	
	
	if (( Rozdil >  50 ) || ( Rozdil < -50 )) IntegralRozdil = 0;		//	rozdil teplot je vic nez 5 stupnu
	if (( Rozdil > -50 ) && ( Rozdil <   0 ) && ( IntegralRozdil > -200000 )) IntegralRozdil--; // rozdil je zaporny, slozka klesa
	if (( Rozdil >   0 ) && ( Rozdil <  50 ) && ( IntegralRozdil <  200000 )) IntegralRozdil++; // rozdil je kladny, slozka roste
	if ( Rozdil < 0 ) Rozdil = 0;
	SolderPWM = (signed int) ((Rozdil * SolderPWM1 / 100) + (IntegralRozdil * SolderPWM2 / 10000));
	
	// * * * * * * * * * * * * * * * * * * vyhodnoti interval a nastavi PWM
	if (  SolderPWM < 0) SolderPWM = 0;
	if (( SolderPWM > 8000 ) || ( Rozdil > 400 )) SolderPWM = 8000;
	OCR1A = SolderPWM;
	
	// * * * * * * * * * * * * * * * * * * rizeni Standby rezimu
	if ( RotStatus == 0 ) StandbyTimer++;			// neni v menu
	if ( StandbyTimer > 999 )						// pocita do jedne sekundy
	{
		StandbyTimer = 0;
		StandbyTimerSec++;
		if (( SolderPWM < ( StandbyOldPower - StandbyDifference )) || ( SolderPWM > ( StandbyOldPower + StandbyDifference )))
		{
			StandbyTimerSec = 0;
		}
		StandbyOldPower = SolderPWM;				// zapamatuje vykon pro pristi srovnani
		
		if ( StandbyTimerSec > StandbyTimerMax )	// prejde do Standby rezimu
		{
			StandbyTempBuff = TempSet;				// schova starou teplotu
			TempSet = StandbyTemp;					// nastavi teplotu Standby
			RotStatus = 100;						// Standby rezim
			StandbyTimerSec = 0;
		}
	}
	
    SREG = 0x80;			// nastavi globalni preruseni
}

/*********************************************************************************
*
* Function Name : ROT_Key
* Description	: vraci delku stisku, po uvolneni koderu na PD2
*
*********************************************************************************/
unsigned char ROT_Key(void)
{
	unsigned char ret;			// hodnota pro navrat
	if (PIND&0x04) 
	{
		ret = RotCounter;
		if (RotCounter > 0) Beep( 3 );
		RotCounter = 0;
		return ret;				// vrati delku stisku
	}
	else
	{
		if (RotCounter == 100)
		{
			return 100;			// stisk je moc dlouhy
		} 
		else
		{
			RotCounter++;
			return 0x00;
		}
	}
}

/*********************************************************************************
*
* Function Name : SYS_Init
* Description	: inicializace portu, preruseni, promennych, displeje
*
*********************************************************************************/
void SYS_Init(void)
{
    // * * * * * * * * * * * * * * * * * * * * * * * * * Aktivace vystupnich portu
    PORTB = 0b00000000;
    DDRB  = 0b00000010;		// pajka, BEEP
    PORTC = 0b00000000;		// H-pull up, L vysok impedance
    DDRC  = 0b00111111;		// H-output, L-input, displej
    PORTD = 0b11111110;		// AD a rot koder
    DDRD  = 0b10100011;
	
	// * * * * * * * * * * * * * * * * * * * * * * * * * Nastaveni preruseni
    GICR  = 0b10000000;		// povoleni preruseni INT1
    MCUCR = 0b00001010;		// aktivace preruseni sestupnou hranou
	
	// * * * * * * * * * * * * * * * * * * * * * * * * * Nastaveni casovace T1
	TCCR1A = 0b10100010;	// Frekvence = F krystal
	TCCR1B = 0b00011001;	// rezim PWM 14
	TIMSK  = 0b00000100;	// preruseni pri preteceni
	ICR1 =	 8000;			// 1000 Hz kmitocet PWM
	OCR1A =  0;				// pajka PWM = 0%
	OCR1B =  4000;			// 50% PWM pro piezomenic

    // * * * * * * * * * * * * * * * * * * * * * * * * * Nastaveni promennych
	AD_CS_Set;
    AD_CLK_Set;
	RotStatus = 0;			// promenne pro rotacni koder
	RotMenu = 0;			// polozka v MENU_Global
	BeepCounter = 0;		// pocita kmity piezomenice
	MeanPointer = 0;		// ukazatel v poli pro mereni
	MeanAdd = 0;			// soucet mereni pro prumer
	TempMenu = 500;			// merena teplota je 50 stupnu
	StandbyTimerSec = 0;	// pocitadlo sekund v casovaci
	
	_delay_ms( 800 );

    // * * * * * * * * * * * * * * * * * * * * * * * * * kontrola obsahu EEPROM	
	if ((EEPROM_Read(0) < 200  ) || (EEPROM_Read(0) > 900  ))
	{
		EEPROM_Write( 0, 400   );	// minimalni nastavitelna teplota
	}
	if ((EEPROM_Read(1) < 1000 ) || (EEPROM_Read(1) > 5000 ))
	{
		EEPROM_Write( 1, 3500  );	// maximalni nastavitelna teplota
	}
	if ((EEPROM_Read(2) < 200  ) || (EEPROM_Read(2) > 5000 ))
	{
		EEPROM_Write( 2, 2800  );	// teplota nastavena na pocatku
	}	
	if ((EEPROM_Read(3) < 200  ) || (EEPROM_Read(3) > 5000 ))
	{
		EEPROM_Write( 3, 1000  );	// teplota pro Standby rezim
	}	
	if ((EEPROM_Read(4) < 8    ) || (EEPROM_Read(4) > 800  ))
	{
		EEPROM_Write( 4, 160   );	// rozdil vykonu, pri kterem se neprejde do Standby
	}	
	if ((EEPROM_Read(5) < 60   ) || (EEPROM_Read(5) > 1200 ))
	{
		EEPROM_Write( 5, 300   );	// cas v sekundach, po kterem se jde do Standby
	}
	if ((EEPROM_Read(6) < 5    ) || (EEPROM_Read(6) > 100  ))
	{
		EEPROM_Write( 6, 20    );	// pocet merenych hodnot v poli
	}
	if ((EEPROM_Read(7) < 500  ) || (EEPROM_Read(7) > 20000))
	{
		EEPROM_Write( 7, 2000  );	// prvni konstanta regulatoru
	}
	if ((EEPROM_Read(8) < 10   ) || (EEPROM_Read(8) > 2000 ))
	{
		EEPROM_Write( 8, 100   );	// druha konstanta regulatoru
	}
	if ((EEPROM_Read(9) < 100  ) || (EEPROM_Read(9) > 1000 ))
	{
		EEPROM_Write( 9, 168   );	// prvni konstanta primky
	}
	if ((EEPROM_Read(10) < 10000) || (EEPROM_Read(10) > 40000))
	{
		EEPROM_Write( 10, 36837 );	// druha konstanta primky
	}
	if ((EEPROM_Read(11) < 100  ) || (EEPROM_Read(11) > 1000 ))
	{
		EEPROM_Write( 11, 157   );	// treti konstanta primky
	}
		
	TempMin				= EEPROM_Read(0);	// minimalni nastavitelna teplota
	TempMax				= EEPROM_Read(1);	// maximalni nastavitelna teplota
	TempSet0			= EEPROM_Read(2);	// teplota nastavena na pocatku
	StandbyTemp			= EEPROM_Read(3);	// teplota pro Standby rezim
	StandbyDifference	= EEPROM_Read(4);	// rozdil vykonu, pri kterem se neprejde do Standby
	StandbyTimerMax		= EEPROM_Read(5);	// cas v sekundach, po kterem se jde do Standby
	TempSet				= TempSet0;			// pozadovana teplota
	MeanMax				= EEPROM_Read(6);	// pocet merenych hodnot v poli
	Const1				= EEPROM_Read(7);	// prvni konstanta regulatoru
	Const2				= EEPROM_Read(8);	// druha konstanta regulatoru
	Primka1				= EEPROM_Read(9);	// prvni konstanta primky
	Primka2				= EEPROM_Read(10);	// druha konstanta primky
	Primka3				= EEPROM_Read(11);	// treti konstanta primky
	
    SREG = 0x80;							// nastavi globalni preruseni
	Beep( 100 );
    
    // * * * * * * * * * * * * * * * * * * * * * * * * * Aktivace displeje HD44780
    LCD_Init();
    LED_Set;
    LCD_WriteCString( "Micro soldering " );
    LCD_Position( 1, 0 );
    LCD_WriteCString( "ver1.1. 12.04.15" );
    _delay_ms( 400 );
	LCD_Clear();
	LCD_WriteCString( "OK2JNJ - ATmega8" );
	LCD_Position( 1, 0 );
	LCD_WriteCString( "Standby mode    " );
    _delay_ms( 800 );
	Beep( 100 );
	LCD_Clear();
}

/*********************************************************************************
*
* Function Name : EEPROM_Read
* Description	: precte unsigned int z EEPROM
*
*********************************************************************************/
unsigned int EEPROM_Read(unsigned char addr)
{
	return(EEPROM_Read1(addr * 2) * 256 + EEPROM_Read1((addr * 2) + 1));
}

/*********************************************************************************
*
* Function Name : EEPROM_Read1
* Description	: precte unsigned int z EEPROM
*
*********************************************************************************/
unsigned char EEPROM_Read1(unsigned char val)
{
	EEARL = val; EEARH = 0;
	EECR |= 0x01; // povoleni cteni z EEPROM
	return( EEDR );
}

/*********************************************************************************
*
* Function Name : EEPROM_Write
* Description	: ulozi unsigned int do EEPROM
*
*********************************************************************************/
void EEPROM_Write(unsigned char addr, unsigned int val)
{
	while(EECR&0x02);						//ceka az EEWE bude 0
	EEARL = (addr * 2); EEARH = 0;
	EEDR = (unsigned char) (val >> 8);		// horni bajt
	EECR |= 0x04;
	EECR |= 0x02;
	while(EECR&0x02);						//ceka az EEWE bude 0
	EEARL = (addr * 2) + 1; EEARH = 0;
	EEDR = (unsigned char) (val & 0x00FF);	// spodni bajt
	EECR |= 0x04;
	EECR |= 0x02;
	_delay_ms( 10 );
}


/*********************************************************************************
*
* Function Name : LTC1286
* Description	: cteni 12 bitu dat z prevodniku
*
*********************************************************************************/
unsigned int LTC1286(void)
{
	unsigned char ADcount;
	unsigned int ADval=0;

	AD_CS_Clr;									// sestupna na CS
	AD_CLK_Clr;
	AD_CLK_Set;									// hodinovy impuls
	AD_CLK_Clr;
	AD_CLK_Set;									// hodinovy impuls
	AD_CLK_Clr;
	
	for(ADcount=0;ADcount<13;ADcount++)
	{
		AD_CLK_Set;								// hodinovy impuls
		AD_CLK_Clr;
		if ((PIND & 0x40) == 0x40) ADval++;		// kdyz je H, bude nulty bit=1
		if(ADcount<12) ADval <<= 1;				// posune prijimana data
	}
	AD_CS_Set;
	return ( ADval );
}

/*********************************************************************************
*
* Function Name : Beep
* Description	: aktivuje PWM 50% a nastavi pocet kmitu 1kHz
*
*********************************************************************************/
void Beep(unsigned int val)
{
	BeepCounter = val;		// pocet kmitu piezomenice
	BEEP_Set;				// bit pro piezomenic je vystupni
}