/*
 * Pajeci_stanice.h
 * Chip: ATmega8
 * Frequency: CPU 8MHz
 * Created: 8.3.2014 20:07:26
 * Author: Merlin
 * Hardware: pajeci stanice
 */ 

/* definice maker */
#define LED_Set		PORTD |= 0x02; // podsviceni displeje
#define LED_Clr		PORTD &=~0x02;
#define AD_CS_Set	PORTD |= 0x80; // aktivace LTC1286
#define AD_CS_Clr	PORTD &=~0x80;
#define AD_CLK_Set	PORTD |= 0x20; // hodiny LTC1286
#define AD_CLK_Clr	PORTD &=~0x20;
#define BEEP_Set	DDRB  |= 0x04; // bit pro speaker je vystupni
#define BEEP_Clr	DDRB  &=~0x04; // bit pro speaker je vstupni

/* uplne funkcni prototypy */
/*********************************************************************************
*
* Function Name : Beep
* Description	: aktivuje PWM 50% a nastavi pocet kmitu 1kHz
*
*********************************************************************************/
void Beep(unsigned int val);

/*********************************************************************************
*
* Function Name : LTC1286
* Description	: cteni 12 bitu dat z prevodniku
*
*********************************************************************************/
unsigned int LTC1286(void);

/*********************************************************************************
*
* Function Name : EEPROM_Write
* Description	: ulozi unsigned int do EEPROM
*
*********************************************************************************/
void EEPROM_Write(unsigned char addr, unsigned int val);

/*********************************************************************************
*
* Function Name : EEPROM_Read1
* Description	: precte unsigned char z EEPROM
*
*********************************************************************************/
unsigned char EEPROM_Read1(unsigned char val);

/*********************************************************************************
*
* Function Name : EEPROM_Read
* Description	: precte unsigned int z EEPROM
*
*********************************************************************************/
unsigned int EEPROM_Read(unsigned char addr);

/*********************************************************************************
*
* Function Name : SYS_Init
* Description	: inicializace portu, preruseni, promennych, displeje
*
*********************************************************************************/
void SYS_Init(void);

/*********************************************************************************
*
* Function Name : ROT_Key
* Description	: vraci delku stisku, po uvolneni koderu na PD2
*
*********************************************************************************/
unsigned char ROT_Key(void);

/*********************************************************************************
*
* Function Name : MENU_Global
* Description	: nastavi promenne a uklada je do EEPROM
*
*********************************************************************************/
void MENU_Global(void);



/* deklarace globalnich promennych modulu pajeci_stanice.c */
volatile unsigned int BeepCounter;				// pocita kmity piezomenice
volatile unsigned char BeepTemp;				// je 0, kdyz je rozdil > 5 stupnu

// * * * * * * * * * * * * * * * * * * * * * * * * Promenne rotacniho koderu
volatile unsigned char RotCounter;				// pocita delku stisku v ROT_Key
volatile unsigned char RotStatus;				// promenne pro rotacni koder, hodnota 100 je pro Standby rezim
volatile unsigned char RotMenu;					// ukazatel v MENU_Global
volatile unsigned char RotTimer;				// pocita cas mezi povolenim preruseni rotacniho koderu

// * * * * * * * * * * * * * * * * * * * * * * * * Promenne AD prevodniku v preruseni casovace
volatile unsigned char MeanPointer;				// ukazatel v poli pro mereni
volatile unsigned int MeanArray[30];			// pole pro mereni
volatile unsigned long int MeanAdd;				// soucet pro prumer
volatile unsigned char MeanMax;					// velikost pole
volatile unsigned long int Mean;				// namereny vysledek
volatile unsigned int MeanOld;					// namereny vysledek z minula
volatile unsigned int TempSolder;				// aktualni teplota pajky

// * * * * * * * * * * * * * * * * * * * * * * * * Mezni hodnoty pro rizeni regulatoru
volatile unsigned int TempSet;					// nastavena teplota pajky
volatile unsigned int TempSet0;					// pocatecni nastavena teplota pajky
volatile unsigned int TempMin, TempMax;			// max a min pro pajku

// * * * * * * * * * * * * * * * * * * * * * * * * Promenne pro vypocet primky
volatile unsigned int Primka1;
volatile unsigned int Primka2;
volatile unsigned int Primka3;

// * * * * * * * * * * * * * * * * * * * * * * * * Promenne regulatoru v preruseni casovace
volatile signed int Rozdil;						// regulacni odchylka
volatile signed long int IntegralRozdil;
volatile signed int SolderPWM;					// vykon PWM
volatile unsigned int TempMenu;					// teplota nastavena v menu
volatile unsigned long int SolderPWM1;
volatile unsigned long int SolderPWM2;			// pomocne promenne regulatoru
volatile unsigned int Const1;					// 1 konstanta regulatoru
volatile unsigned int Const2;					// 2 konstanta regulatoru

// * * * * * * * * * * * * * * * * * * * * * * * * Promenne standby
volatile signed int StandbyTimer;				// pocita preruseni pro sekundy
volatile signed int StandbyTimerSec;			// pocita sekundy
volatile signed int StandbyTimerMax;			// hodnota pri ktere se prejde do Standby nastavit v EEPROM
volatile signed int StandbyOldPower;			// vykon pro porovnani
volatile signed int StandbyDifference;			// rozdil pri kterem sepne Standby nastavit v EEPROM
volatile signed int StandbyTemp;				// teplota pro Standby nastavit v EEPROM
volatile signed int StandbyTempBuff;			// schova starou teplotu